<?php declare(strict_types=1);

namespace BitBadger\PDODocument\Query;

use BitBadger\PDODocument\{Field, Query};

/**
 * Queries to delete documents
 */
class Delete
{
    /**
     * Query to delete a document by its ID
     *
     * @param string $tableName The name of the table from which a document should be deleted
     * @return string The DELETE statement to delete a document by its ID
     */
    public static function byId(string $tableName): string
    {
        return "DELETE FROM $tableName WHERE " . Query::whereById();
    }

    /**
     * Query to delete documents using a comparison on JSON fields
     *
     * @param string $tableName The name of the table from which documents should be deleted
     * @param Field[] $fields The field comparison to match
     * @param string $conjunction How to handle multiple conditions (optional; defaults to `AND`)
     * @return string The DELETE statement to delete documents via field comparison
     */
    public static function byFields(string $tableName, array $fields, string $conjunction = 'AND'): string
    {
        return "DELETE FROM $tableName WHERE " . Query::whereByFields($fields, $conjunction);
    }
}
