<?php declare(strict_types=1);

namespace BitBadger\PDODocument;

/**
 * Functions to remove fields from documents
 */
class RemoveFields
{
    /**
     * Remove fields from a document by the document's ID
     *
     * @param string $tableName The table in which the document should have fields removed
     * @param mixed $docId The ID of the document from which fields should be removed
     * @param array|string[] $fieldNames The names of the fields to be removed
     * @throws DocumentException If any is encountered
     */
    public static function byId(string $tableName, mixed $docId, array $fieldNames): void
    {
        $nameParams = Parameters::fieldNames(':name', $fieldNames);
        Custom::nonQuery(Query\RemoveFields::byId($tableName, $nameParams),
            array_merge(Parameters::id($docId), $nameParams));
    }

    /**
     * Remove fields from documents via a comparison on a JSON field in the document
     *
     * @param string $tableName The table in which documents should have fields removed
     * @param array|Field[] $fields The field comparison to match
     * @param array|string[] $fieldNames The names of the fields to be removed
     * @param string $conjunction How to handle multiple conditions (optional; defaults to `AND`)
     * @throws DocumentException If any is encountered
     */
    public static function byFields(string $tableName, array $fields, array $fieldNames,
                                    string $conjunction = 'AND'): void
    {
        $nameParams  = Parameters::fieldNames(':name', $fieldNames);
        $namedFields = Parameters::nameFields($fields);
        Custom::nonQuery(Query\RemoveFields::byFields($tableName, $namedFields, $nameParams, $conjunction),
            Parameters::addFields($namedFields, $nameParams));
    }
}
